/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvControlSlice.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"
#include "HvControlUnop.h"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvMath.h"
#include "HvSignalLine.h"
#include "HvSignalBiquad.h"
#include "HvControlIf.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_jR6LQmDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hu9t0ZGE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_p88jmWSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xWfxpODF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jMe3trYS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ERi54sF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6vgiU36F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fJWOsytQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iuV04dgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lPJ7Kac7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fdUramuD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oFwntC99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x5oP5Tcq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eo2a9mFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VQJ20GeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ca2v5stC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wFoXDxnP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XeJdZjLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zegVO73N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UMhMemUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0WXtZGcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HeR1bPmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0SSKcOIO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FEiUNQuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h6eZUqSd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_90nkjVhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZpMWTA12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TJL35w12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DT0cuwEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_czY5lvAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VkNX5Qzf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EgniqhLy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2GGOWwqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nBcfh5JG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_99vvawyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5LETKEco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xkREBcJs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qJzKeJTi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2rITz84s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Pd0VTA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yF9xQhGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8nSyddlv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9CYmGT0y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WLfERHja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LCRpEFDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TRBOxw1L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W6bqHOQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20IBNC3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U7EyBLxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uOP8Psqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m2w8buie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y5Fzst1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KaHWgqpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K5mrCo3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l1YdJQyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3Jnn7z04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XjXEMLXB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PIM7zKX5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LhKrhh0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OVwfEezR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1YfnQNck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JH0feovq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jXKFu0wG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DMWqNfKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZPldY6b4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zNqxwCq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LlInUCa5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xao0teKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JSVtnCmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9kVpxk3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_abA1T0pR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5OpoNHE0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2fYog2CZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yzNfbLYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wOgnvWYu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DwDrQdOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zmmWZtXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QaYLtO2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_L1aPREyt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_YZopBRiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rMxbk7XD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pKakZAaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xinHSdLg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7ss6mrIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1PZOpDU6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_lHYpxuUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QdDHarbo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qEmVEvW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_55a9xp0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2ojauJzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NlzNdXmr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5vCxgmwE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_b2N2KHSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yITf7A2J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jJRHvzPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3O8s4U8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2kNFbonx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zy98sRBQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DkxTyfCO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_btJbAtDN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aB2scd2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SYArllNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wtyvcLMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZaSJWya3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o5yu32N1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bmHrMCp8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mfCl0EhF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qckoaVTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_N595kDHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rgihVOij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iKXf0yGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yvq8eZeX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TyNCMZnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xZModIXV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RA9Fh9N0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oL40cZol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bvdoFroT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XHza8N0s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8gnVN4Bb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jVXWZIna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ALeprX6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xsr3cgXW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aU3FETo4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v0yr9H2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XjpF1nK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lfGKn0et_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lan8SMZ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zxbMburV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UITEr5la_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_r3uJKQLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VP0hn1LK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dpzmWhHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A4sZQ81G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_llvTrYCS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iD8iNreS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wynb2sPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TpuJKk89_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jb8UW9YJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CphboQjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kSw4Kqyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7YhuaILb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uWxTS6aH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xfUzDyWG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7nGpbSjt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zdF3mwZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sPo3HTwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o8r9z7Nc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YOeXW8SO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9mUa5o8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mJO7KPRT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uMmR7NZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gz4VxL0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iIWDKJ2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qiWbflH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_htwxsHyB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5pOgQrmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jp0M7GgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mv8MZ5B0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lClskFiu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4I0oJCf8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jOwb2sQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wyU8Ut2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VgCKUg22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x1rm3Kje_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ZbR07Bft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3LERnXib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sahk3t7d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZI6hp5mZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_04xC21w4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dkBi7ju3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YLVtW7Ha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TZjWWy8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ckBCvs43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZPoEER9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Asrtl6pg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FF93YLvV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YoP3VLL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7HOtjjir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uCDlZRhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yavpGOC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WesxUaeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_SI5N3hq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vLRV1MB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R4OYTaR9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aOmIofQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GeGvr3Oe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xSkHqZqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TYIrvyDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y2NbB2kU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pBvEOwqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_34EZDMws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TTgM7UXk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yQMnqrCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Twjbn1nc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CzihH7D2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tiaOt0mN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fnIHUo2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HXQYMQq7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f6QlNeMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YmvNFQO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0uwKIF9L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dsd4AXJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gIXij6tD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hcPKx5pw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O9hqzuHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5vhsAUJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LHrffh6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_djdRhhql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DrsnxyyL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c3rnbLM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v6rcBUre_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i0BuyQBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cwv0n0nu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rMtWnQWK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IatBf0HT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EIVvwYPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IVBqHn9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wdAOnEZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lFpu7gee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U6IfNF2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TpYJj7Zr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g04HkIix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KJTFX6hd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kq8cJ5AJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m3B4Lts4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w0H6Eo8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yMElY95W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5gWSfsSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G2yq7spQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_32PNfbFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sic9MGN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oqr0ePaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gGDqVmN3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ulx1pPmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w6ediJWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OYMzjbHP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cz5yvuwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_H78OVDsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IA8MjLTp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bxlpCBBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NibO8FRQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_irICAiZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nPIj9Dcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sQiGHKCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kJgpmTmv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NtJSDvqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D8o8vYSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vqi9OYZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wT4jc7UM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SfOQRH8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FZD4qPxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EIP8BsFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Inni5gCD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NG0eM9PC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZgJGFVJb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eWxEaXKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6FReg2H4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PrfnKxOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uNyqayhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qtQ5UvIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5IMcpYja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vIG0tccS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vjERy8sP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bep8WhSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nwoTKLvi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Cl32bYkC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_FWP0iEYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0IK5MlJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yz2uC2hW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZqmQOpJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RpALQ8jY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LNSRre1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WMWGkGfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mCIv7Iks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6SfOWZaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NSPThJkc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RURlEkzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_psOl43Xs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OJDkIi0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JmuLZ6F5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G5s79VTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IYoN9fVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oDNV8GWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zx0FPTFy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_btoZ6iI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vs89tYpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_puNC4FeN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q4joiynj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TfFb5AcR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hMo3Cpaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ui2d4TXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1isjUBzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QEatkrc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XPURx8if_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WMdSKUiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YMowjVSx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6q73QilO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gT5F86mE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iwXQCphQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_faiOkuYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RxNPvtev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UTTnzL3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k0AoZSGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bpc2iY9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Zonuzs6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xRvaK9Hb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_luShR2qb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MVG8y84I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gw0P60q4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lQFoxM23_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MkZQpYY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kAk2nDg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E6QbITAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6v6NVf5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OPV44hOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w8nnkKme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dJW328mW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_R6nf4AoG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fVaGwnWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rLFpzuof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gvMEXQAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p6ysQsMk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gGelR6qt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aFGC6t5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tIYQ1Lqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XwFxRTsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mgrad0kc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6w0hz103_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xoftbGwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cVRakZw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9aqTDCgl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JAAOYYgq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ziv4Szt7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x8k89JlU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wVguzM5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IXpwXYPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yqbmjXMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QQIEPmwA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JRUSUJGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Nreagtbb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_HMLN4ATT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1dk98Dpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gtIus0jM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WbHIBVvW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_uanfLJcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2pSlo38w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3zMlfUGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6yDgWTSU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_0G5I1qhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_50C7UunF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tPCHAaP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_spdKu6hp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_M6LPjsmB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xAJlwTbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FOq02q3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4cF3qelY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MC8k9bWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1tk6yV5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EWvj0bJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WU1vx70S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xWIhQTCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_F2Z2xAT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fNs6VT8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6kQiK3aN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_daHJgWdV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tWVvvT1k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z0COrigM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_obsy7Te9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nrOiDEvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uVWAf7V2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_COPNTlpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tFazhFF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ozuVIZuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tGxyRxDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cecNrKIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yTXa8iXA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qDYyfZ6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0hy5AUAA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V0GfTFuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YoqATDUs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tcHhN8Bu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mUoEMsPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DrOsq9if_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XrApD5RB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hlsgpU9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tp4yvzUz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eBvrwq5S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yLEOdl0r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OuAKee01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pttSUdtu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_lKfJ5D9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DK1A7EFh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YNTCLpYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_paJobGg6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_91t8vYkS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sWIawRMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AJ2MVVDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9utTVBYu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dEMOq3d7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XBpSyLyp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ildD80fG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JbCaoDyp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KVnqChNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LobJ3X5v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gzReOKe8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2p5cDElN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kB3xPzvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nQxcZ738_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EaRNhXJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y94VP0k1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nWDWoNvS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g5c9QAYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TzCvoDVm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GrnG1vwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jLblHj73_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rUovXJRt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jF84ml8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F6ccr0Jw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_At431eKk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0KPURpHT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_51jHOGjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GXS8Tmsx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NkU0Y2Jm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wCzrqQz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NaxQzT4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_U16zFDr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9KDwIqIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_50sdpWae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1YAEtSVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oTgCEmjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RFwNwJEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DU40Dnqs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DCR8YCB9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rUqIZhED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JvOGHvMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KP830iDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3StiYsDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ql7d0i8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TNKRroM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_izB781Ra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gSJKAbAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9XPO4fgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QixQkigC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2GoUAYwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mNwnbx21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Q9DYceq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LCidfCYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WsI9LPjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_btmPMSfb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NvPHAuaN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M2UJYIcO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B73S8ozA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fQoUaQv8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2PHOlS2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b9YnVRl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lnUYSSvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AhFqmirS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ILCVdDST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9CCxDimO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kv97UwZd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0XFmKodN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RDxFOAmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ONMaV3sP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2u5UgRTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QGnB0eKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1qtFdHIz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DkhhdKU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9jWLgafD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OTYSqysp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_W6XchiOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5UuLqYlm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sgVBsRdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pprr5pwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j0nSGI1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eDRThMUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5tnD4FJN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_WHg3Dain_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z0hT8cj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VXXsLlSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oetYKDMq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K46YAeaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e2PZLl46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SkxIGYi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mgcC479C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m4PGFqS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uwq7W8Qx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OAbZAhQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A0mo9PiN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tE3J0Glt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U1yqhbTz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F60IAv83_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BUXUgl2D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KGc3JtQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f0rTCz3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QnqRtE5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KCFupp6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k4p1AFXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uI4qDCK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bOqQA5tP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ILKp9Ong_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pK4bhkr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6k62MvVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7GBZQahs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yfuYtUtN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0RHyMLa0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o6x3p4jH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zoxisabz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0JQXe0Bz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TvfOVPPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5fzPqa1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cdU9ucsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A2xeNuaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W0VmsakG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uVAxifez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EkFhDmiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UQJMwYZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oWycLqqH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LNtOxSEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iBTXr2p7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M8skO7Wx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u4dx4QM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_minTaZuD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iWt2Mw6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C8MDlGJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GQat40Fi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GjOa92Wc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MnJ8ysBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4B7YVJpz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PdSSrYJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_eci1TIgQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ygLO6LdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OmBJ9tDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DuHkqFR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cFeQCLO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RltIj9Ib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EeFadROy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_h9FGWrYj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O4vf01CX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xvBrlnR7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iUyvtZAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eEpK9I0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z1eiylHT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TRyNOaxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VA3ikGL4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_toB5KbGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q4fIRepv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z8sqZFu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Tta34mmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HRdEwSMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8a5KIfN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UNlY3RdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5Xn9UTQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RYHbJdQk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9aWy91uk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WG4AzsqV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TLXuO23e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QxHIo4oY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9TVUUmEW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_j7Cy4it0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r0phQYrz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NjlkeTyi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9gglx4Rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fB2LZ6mg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8PO9KVqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UnqFFYdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oKwmmp9l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1s91C4ee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CKcSLZe8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1tw84Dlh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_taw2xMs4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sWOU9Ez1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rBq6vVHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yYqxq99t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3WCaxAeb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_InLDcuxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TzZrkRss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HfKK8hg4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MbKvlRdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Q7qnlNxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WRhUeBAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nnl1b4QD_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_O3nHn3Ms;
  SignalLine sLine_0SOisfAi;
  SignalLine sLine_zSDPAtTR;
  SignalLine sLine_TkpjTkU4;
  SignalLine sLine_2YFvEdlw;
  SignalBiquad sBiquad_s_L0wx5m7x;
  SignalLine sLine_RX9Rt7V5;
  SignalLine sLine_pdTALLqu;
  SignalLine sLine_Me4kh6A0;
  SignalLine sLine_gjCJSX0T;
  SignalBiquad sBiquad_s_7NIAuwlb;
  SignalLine sLine_QivctcJm;
  SignalLine sLine_xhXTdJxB;
  SignalLine sLine_ySQuIKOt;
  SignalLine sLine_sGVFRZuB;
  SignalLine sLine_5zYAF9uX;
  SignalBiquad sBiquad_s_FMtR4gzb;
  SignalLine sLine_JbsYuMyX;
  SignalLine sLine_KJnRgbRc;
  SignalLine sLine_AIFRgkeT;
  SignalLine sLine_LpgV3paW;
  SignalLine sLine_UAdmxef8;
  SignalBiquad sBiquad_s_trU8Untm;
  SignalLine sLine_XU7zAlrO;
  SignalLine sLine_tzoZym8h;
  SignalLine sLine_8zxoC1ga;
  SignalLine sLine_pubH4jLX;
  SignalBiquad sBiquad_s_ldTwZ7lA;
  SignalLine sLine_pwDN8aVu;
  SignalLine sLine_vXPSzXpM;
  SignalLine sLine_vQPXzreO;
  SignalLine sLine_sSudC3EV;
  SignalLine sLine_T18fqQ5A;
  SignalBiquad sBiquad_s_TqKaXDwl;
  ControlVar cVar_jR6LQmDP;
  ControlVar cVar_hu9t0ZGE;
  ControlVar cVar_p88jmWSr;
  ControlVar cVar_xWfxpODF;
  ControlSlice cSlice_ERi54sF2;
  ControlVar cVar_6vgiU36F;
  ControlVar cVar_iuV04dgX;
  ControlIf cIf_lPJ7Kac7;
  ControlIf cIf_fdUramuD;
  ControlBinop cBinop_x5oP5Tcq;
  ControlBinop cBinop_Eo2a9mFr;
  ControlBinop cBinop_wFoXDxnP;
  ControlBinop cBinop_XeJdZjLM;
  ControlBinop cBinop_UMhMemUl;
  ControlIf cIf_0WXtZGcN;
  ControlBinop cBinop_HeR1bPmb;
  ControlBinop cBinop_0SSKcOIO;
  ControlBinop cBinop_h6eZUqSd;
  ControlBinop cBinop_90nkjVhD;
  ControlBinop cBinop_ZpMWTA12;
  ControlVar cVar_EgniqhLy;
  ControlIf cIf_2GGOWwqC;
  ControlIf cIf_nBcfh5JG;
  ControlBinop cBinop_5LETKEco;
  ControlBinop cBinop_xkREBcJs;
  ControlBinop cBinop_6Pd0VTA1;
  ControlBinop cBinop_yF9xQhGK;
  ControlBinop cBinop_9CYmGT0y;
  ControlIf cIf_WLfERHja;
  ControlBinop cBinop_LCRpEFDm;
  ControlBinop cBinop_TRBOxw1L;
  ControlBinop cBinop_20IBNC3o;
  ControlBinop cBinop_U7EyBLxR;
  ControlBinop cBinop_uOP8Psqa;
  ControlVar cVar_l1YdJQyP;
  ControlIf cIf_3Jnn7z04;
  ControlIf cIf_XjXEMLXB;
  ControlBinop cBinop_LhKrhh0q;
  ControlBinop cBinop_OVwfEezR;
  ControlBinop cBinop_jXKFu0wG;
  ControlBinop cBinop_DMWqNfKq;
  ControlBinop cBinop_zNqxwCq3;
  ControlIf cIf_LlInUCa5;
  ControlBinop cBinop_xao0teKM;
  ControlBinop cBinop_JSVtnCmQ;
  ControlBinop cBinop_abA1T0pR;
  ControlBinop cBinop_5OpoNHE0;
  ControlBinop cBinop_2fYog2CZ;
  ControlIf cIf_QaYLtO2n;
  ControlSlice cSlice_YZopBRiX;
  ControlVar cVar_rMxbk7XD;
  ControlSlice cSlice_7ss6mrIB;
  ControlVar cVar_1PZOpDU6;
  ControlSlice cSlice_qEmVEvW0;
  ControlVar cVar_55a9xp0p;
  ControlSlice cSlice_5vCxgmwE;
  ControlVar cVar_b2N2KHSP;
  ControlBinop cBinop_ZaSJWya3;
  ControlBinop cBinop_bmHrMCp8;
  ControlBinop cBinop_mfCl0EhF;
  ControlBinop cBinop_rgihVOij;
  ControlBinop cBinop_iKXf0yGB;
  ControlBinop cBinop_Yvq8eZeX;
  ControlBinop cBinop_TyNCMZnK;
  ControlBinop cBinop_xZModIXV;
  ControlVar cVar_RA9Fh9N0;
  ControlBinop cBinop_oL40cZol;
  ControlBinop cBinop_bvdoFroT;
  ControlBinop cBinop_XHza8N0s;
  ControlBinop cBinop_8gnVN4Bb;
  ControlBinop cBinop_jVXWZIna;
  ControlBinop cBinop_ALeprX6E;
  ControlBinop cBinop_Xsr3cgXW;
  ControlBinop cBinop_v0yr9H2b;
  ControlVar cVar_XjpF1nK9;
  ControlVar cVar_lfGKn0et;
  ControlBinop cBinop_A4sZQ81G;
  ControlBinop cBinop_llvTrYCS;
  ControlBinop cBinop_iD8iNreS;
  ControlBinop cBinop_TpuJKk89;
  ControlBinop cBinop_Jb8UW9YJ;
  ControlBinop cBinop_CphboQjS;
  ControlBinop cBinop_kSw4Kqyb;
  ControlBinop cBinop_7YhuaILb;
  ControlBinop cBinop_uWxTS6aH;
  ControlBinop cBinop_jOwb2sQQ;
  ControlBinop cBinop_VgCKUg22;
  ControlBinop cBinop_x1rm3Kje;
  ControlBinop cBinop_sahk3t7d;
  ControlBinop cBinop_ZI6hp5mZ;
  ControlBinop cBinop_04xC21w4;
  ControlBinop cBinop_dkBi7ju3;
  ControlBinop cBinop_YLVtW7Ha;
  ControlBinop cBinop_TZjWWy8Y;
  ControlBinop cBinop_ckBCvs43;
  ControlBinop cBinop_Asrtl6pg;
  ControlVar cVar_FF93YLvV;
  ControlVar cVar_YoP3VLL0;
  ControlVar cVar_7HOtjjir;
  ControlBinop cBinop_aOmIofQo;
  ControlBinop cBinop_GeGvr3Oe;
  ControlBinop cBinop_xSkHqZqI;
  ControlBinop cBinop_y2NbB2kU;
  ControlBinop cBinop_pBvEOwqa;
  ControlBinop cBinop_34EZDMws;
  ControlBinop cBinop_TTgM7UXk;
  ControlBinop cBinop_yQMnqrCN;
  ControlBinop cBinop_v6rcBUre;
  ControlBinop cBinop_cwv0n0nu;
  ControlBinop cBinop_rMtWnQWK;
  ControlBinop cBinop_IVBqHn9D;
  ControlBinop cBinop_wdAOnEZ3;
  ControlBinop cBinop_lFpu7gee;
  ControlBinop cBinop_U6IfNF2n;
  ControlBinop cBinop_TpYJj7Zr;
  ControlBinop cBinop_KJTFX6hd;
  ControlBinop cBinop_m3B4Lts4;
  ControlBinop cBinop_w0H6Eo8k;
  ControlBinop cBinop_5gWSfsSu;
  ControlBinop cBinop_G2yq7spQ;
  ControlBinop cBinop_32PNfbFL;
  ControlBinop cBinop_Oqr0ePaQ;
  ControlVar cVar_gGDqVmN3;
  ControlVar cVar_Ulx1pPmJ;
  ControlVar cVar_w6ediJWL;
  ControlBinop cBinop_irICAiZn;
  ControlBinop cBinop_nPIj9Dcu;
  ControlBinop cBinop_sQiGHKCj;
  ControlBinop cBinop_NtJSDvqB;
  ControlBinop cBinop_D8o8vYSV;
  ControlBinop cBinop_vqi9OYZ4;
  ControlBinop cBinop_wT4jc7UM;
  ControlBinop cBinop_SfOQRH8Y;
  ControlBinop cBinop_FZD4qPxC;
  ControlBinop cBinop_vIG0tccS;
  ControlBinop cBinop_bep8WhSe;
  ControlBinop cBinop_nwoTKLvi;
  SignalVarf sVarf_ISv0Xv5s;
  SignalVarf sVarf_bYuNVGQS;
  SignalVarf sVarf_1aLfzKoY;
  ControlSlice cSlice_FWP0iEYy;
  ControlVar cVar_0IK5MlJ1;
  ControlVar cVar_ZqmQOpJV;
  ControlIf cIf_RpALQ8jY;
  ControlIf cIf_LNSRre1K;
  ControlBinop cBinop_mCIv7Iks;
  ControlBinop cBinop_6SfOWZaL;
  ControlBinop cBinop_psOl43Xs;
  ControlBinop cBinop_OJDkIi0m;
  ControlBinop cBinop_G5s79VTr;
  ControlIf cIf_IYoN9fVT;
  ControlBinop cBinop_oDNV8GWW;
  ControlBinop cBinop_Zx0FPTFy;
  ControlBinop cBinop_Vs89tYpy;
  ControlBinop cBinop_puNC4FeN;
  ControlBinop cBinop_q4joiynj;
  ControlVar cVar_QEatkrc1;
  ControlIf cIf_XPURx8if;
  ControlIf cIf_WMdSKUiE;
  ControlBinop cBinop_6q73QilO;
  ControlBinop cBinop_gT5F86mE;
  ControlBinop cBinop_RxNPvtev;
  ControlBinop cBinop_UTTnzL3g;
  ControlBinop cBinop_bpc2iY9X;
  ControlIf cIf_Zonuzs6J;
  ControlBinop cBinop_xRvaK9Hb;
  ControlBinop cBinop_luShR2qb;
  ControlBinop cBinop_gw0P60q4;
  ControlBinop cBinop_lQFoxM23;
  ControlBinop cBinop_MkZQpYY4;
  ControlVar cVar_w8nnkKme;
  ControlIf cIf_dJW328mW;
  ControlIf cIf_R6nf4AoG;
  ControlBinop cBinop_rLFpzuof;
  ControlBinop cBinop_gvMEXQAU;
  ControlBinop cBinop_aFGC6t5i;
  ControlBinop cBinop_tIYQ1Lqn;
  ControlBinop cBinop_mgrad0kc;
  ControlIf cIf_6w0hz103;
  ControlBinop cBinop_xoftbGwU;
  ControlBinop cBinop_cVRakZw1;
  ControlBinop cBinop_JAAOYYgq;
  ControlBinop cBinop_Ziv4Szt7;
  ControlBinop cBinop_x8k89JlU;
  ControlIf cIf_JRUSUJGN;
  ControlSlice cSlice_HMLN4ATT;
  ControlVar cVar_1dk98Dpa;
  ControlSlice cSlice_uanfLJcN;
  ControlVar cVar_2pSlo38w;
  ControlSlice cSlice_0G5I1qhS;
  ControlVar cVar_50C7UunF;
  ControlSlice cSlice_M6LPjsmB;
  ControlVar cVar_xAJlwTbP;
  ControlBinop cBinop_daHJgWdV;
  ControlBinop cBinop_Z0COrigM;
  ControlBinop cBinop_obsy7Te9;
  ControlBinop cBinop_COPNTlpk;
  ControlBinop cBinop_tFazhFF4;
  ControlBinop cBinop_ozuVIZuI;
  ControlBinop cBinop_tGxyRxDY;
  ControlBinop cBinop_cecNrKIA;
  ControlVar cVar_yTXa8iXA;
  ControlBinop cBinop_qDYyfZ6E;
  ControlBinop cBinop_0hy5AUAA;
  ControlBinop cBinop_V0GfTFuC;
  ControlBinop cBinop_YoqATDUs;
  ControlBinop cBinop_tcHhN8Bu;
  ControlBinop cBinop_mUoEMsPK;
  ControlBinop cBinop_DrOsq9if;
  ControlBinop cBinop_hlsgpU9g;
  ControlVar cVar_tp4yvzUz;
  ControlVar cVar_eBvrwq5S;
  ControlBinop cBinop_paJobGg6;
  ControlBinop cBinop_91t8vYkS;
  ControlBinop cBinop_sWIawRMz;
  ControlBinop cBinop_9utTVBYu;
  ControlBinop cBinop_dEMOq3d7;
  ControlBinop cBinop_XBpSyLyp;
  ControlBinop cBinop_ildD80fG;
  ControlBinop cBinop_JbCaoDyp;
  ControlBinop cBinop_KVnqChNH;
  ControlBinop cBinop_GXS8Tmsx;
  ControlBinop cBinop_wCzrqQz8;
  ControlBinop cBinop_NaxQzT4X;
  ControlBinop cBinop_50sdpWae;
  ControlBinop cBinop_1YAEtSVh;
  ControlBinop cBinop_oTgCEmjh;
  ControlBinop cBinop_RFwNwJEy;
  ControlBinop cBinop_DU40Dnqs;
  ControlBinop cBinop_DCR8YCB9;
  ControlBinop cBinop_rUqIZhED;
  ControlBinop cBinop_KP830iDL;
  ControlVar cVar_3StiYsDb;
  ControlVar cVar_ql7d0i8F;
  ControlVar cVar_TNKRroM5;
  ControlBinop cBinop_6Q9DYceq;
  ControlBinop cBinop_LCidfCYi;
  ControlBinop cBinop_WsI9LPjb;
  ControlBinop cBinop_NvPHAuaN;
  ControlBinop cBinop_M2UJYIcO;
  ControlBinop cBinop_B73S8ozA;
  ControlBinop cBinop_fQoUaQv8;
  ControlBinop cBinop_2PHOlS2R;
  ControlBinop cBinop_sgVBsRdE;
  ControlBinop cBinop_j0nSGI1W;
  ControlBinop cBinop_eDRThMUM;
  ControlBinop cBinop_z0hT8cj1;
  ControlBinop cBinop_VXXsLlSK;
  ControlBinop cBinop_oetYKDMq;
  ControlBinop cBinop_K46YAeaA;
  ControlBinop cBinop_e2PZLl46;
  ControlBinop cBinop_mgcC479C;
  ControlBinop cBinop_Uwq7W8Qx;
  ControlBinop cBinop_OAbZAhQT;
  ControlBinop cBinop_tE3J0Glt;
  ControlBinop cBinop_U1yqhbTz;
  ControlBinop cBinop_F60IAv83;
  ControlBinop cBinop_KGc3JtQx;
  ControlVar cVar_f0rTCz3V;
  ControlVar cVar_QnqRtE5l;
  ControlVar cVar_KCFupp6a;
  ControlBinop cBinop_7GBZQahs;
  ControlBinop cBinop_yfuYtUtN;
  ControlBinop cBinop_0RHyMLa0;
  ControlBinop cBinop_zoxisabz;
  ControlBinop cBinop_0JQXe0Bz;
  ControlBinop cBinop_TvfOVPPM;
  ControlBinop cBinop_5fzPqa1J;
  ControlBinop cBinop_cdU9ucsZ;
  ControlBinop cBinop_A2xeNuaG;
  ControlBinop cBinop_iWt2Mw6E;
  ControlBinop cBinop_GQat40Fi;
  ControlBinop cBinop_GjOa92Wc;
  SignalVarf sVarf_G0HKvdQW;
  SignalVarf sVarf_FZo7Nmp8;
  SignalVarf sVarf_nXoiuc1I;
  SignalVarf sVarf_8TBYdQtc;
  SignalVarf sVarf_t0iHwBAU;
  SignalVarf sVarf_DYdNKAJ7;
  SignalVarf sVarf_N7vnEvhw;
  SignalVarf sVarf_ytfpN0UH;
  SignalVarf sVarf_v2D4gYwK;
  ControlVar cVar_MnJ8ysBm;
  ControlVar cVar_4B7YVJpz;
  ControlBinop cBinop_cFeQCLO8;
  ControlBinop cBinop_RltIj9Ib;
  ControlBinop cBinop_EeFadROy;
  ControlBinop cBinop_O4vf01CX;
  ControlBinop cBinop_xvBrlnR7;
  ControlBinop cBinop_iUyvtZAt;
  ControlBinop cBinop_eEpK9I0Z;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
