/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_O3nHn3Ms);
  numBytes += sLine_init(&sLine_0SOisfAi);
  numBytes += sLine_init(&sLine_zSDPAtTR);
  numBytes += sLine_init(&sLine_TkpjTkU4);
  numBytes += sLine_init(&sLine_2YFvEdlw);
  numBytes += sBiquad_init(&sBiquad_s_L0wx5m7x);
  numBytes += sLine_init(&sLine_RX9Rt7V5);
  numBytes += sLine_init(&sLine_pdTALLqu);
  numBytes += sLine_init(&sLine_Me4kh6A0);
  numBytes += sLine_init(&sLine_gjCJSX0T);
  numBytes += sBiquad_init(&sBiquad_s_7NIAuwlb);
  numBytes += sLine_init(&sLine_QivctcJm);
  numBytes += sLine_init(&sLine_xhXTdJxB);
  numBytes += sLine_init(&sLine_ySQuIKOt);
  numBytes += sLine_init(&sLine_sGVFRZuB);
  numBytes += sLine_init(&sLine_5zYAF9uX);
  numBytes += sBiquad_init(&sBiquad_s_FMtR4gzb);
  numBytes += sLine_init(&sLine_JbsYuMyX);
  numBytes += sLine_init(&sLine_KJnRgbRc);
  numBytes += sLine_init(&sLine_AIFRgkeT);
  numBytes += sLine_init(&sLine_LpgV3paW);
  numBytes += sLine_init(&sLine_UAdmxef8);
  numBytes += sBiquad_init(&sBiquad_s_trU8Untm);
  numBytes += sLine_init(&sLine_XU7zAlrO);
  numBytes += sLine_init(&sLine_tzoZym8h);
  numBytes += sLine_init(&sLine_8zxoC1ga);
  numBytes += sLine_init(&sLine_pubH4jLX);
  numBytes += sBiquad_init(&sBiquad_s_ldTwZ7lA);
  numBytes += sLine_init(&sLine_pwDN8aVu);
  numBytes += sLine_init(&sLine_vXPSzXpM);
  numBytes += sLine_init(&sLine_vQPXzreO);
  numBytes += sLine_init(&sLine_sSudC3EV);
  numBytes += sLine_init(&sLine_T18fqQ5A);
  numBytes += sBiquad_init(&sBiquad_s_TqKaXDwl);
  numBytes += cVar_init_f(&cVar_jR6LQmDP, 0.0f);
  numBytes += cVar_init_f(&cVar_hu9t0ZGE, 0.0f);
  numBytes += cVar_init_f(&cVar_p88jmWSr, 0.0f);
  numBytes += cVar_init_f(&cVar_xWfxpODF, 0.0f);
  numBytes += cSlice_init(&cSlice_ERi54sF2, 1, -1);
  numBytes += cVar_init_f(&cVar_6vgiU36F, 1337.0f);
  numBytes += cVar_init_f(&cVar_iuV04dgX, 0.0f);
  numBytes += cIf_init(&cIf_lPJ7Kac7, false);
  numBytes += cIf_init(&cIf_fdUramuD, false);
  numBytes += cBinop_init(&cBinop_x5oP5Tcq, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0WXtZGcN, false);
  numBytes += cBinop_init(&cBinop_h6eZUqSd, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_90nkjVhD, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ZpMWTA12, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_EgniqhLy, 0.0f);
  numBytes += cIf_init(&cIf_2GGOWwqC, false);
  numBytes += cIf_init(&cIf_nBcfh5JG, false);
  numBytes += cBinop_init(&cBinop_5LETKEco, 0.0f); // __pow
  numBytes += cIf_init(&cIf_WLfERHja, false);
  numBytes += cBinop_init(&cBinop_20IBNC3o, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_U7EyBLxR, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_uOP8Psqa, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_l1YdJQyP, 0.0f);
  numBytes += cIf_init(&cIf_3Jnn7z04, false);
  numBytes += cIf_init(&cIf_XjXEMLXB, false);
  numBytes += cBinop_init(&cBinop_LhKrhh0q, 0.0f); // __pow
  numBytes += cIf_init(&cIf_LlInUCa5, false);
  numBytes += cBinop_init(&cBinop_abA1T0pR, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_5OpoNHE0, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2fYog2CZ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_QaYLtO2n, false);
  numBytes += cSlice_init(&cSlice_YZopBRiX, 1, -1);
  numBytes += cVar_init_f(&cVar_rMxbk7XD, 0.0f);
  numBytes += cSlice_init(&cSlice_7ss6mrIB, 1, -1);
  numBytes += cVar_init_f(&cVar_1PZOpDU6, 0.0f);
  numBytes += cSlice_init(&cSlice_qEmVEvW0, 1, -1);
  numBytes += cVar_init_f(&cVar_55a9xp0p, 0.0f);
  numBytes += cSlice_init(&cSlice_5vCxgmwE, 1, -1);
  numBytes += cVar_init_f(&cVar_b2N2KHSP, 0.313f);
  numBytes += cBinop_init(&cBinop_bmHrMCp8, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mfCl0EhF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_RA9Fh9N0, 0.0f);
  numBytes += cVar_init_f(&cVar_XjpF1nK9, 1337.0f);
  numBytes += cVar_init_f(&cVar_lfGKn0et, 0.3f);
  numBytes += cBinop_init(&cBinop_llvTrYCS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Jb8UW9YJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CphboQjS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kSw4Kqyb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7YhuaILb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uWxTS6aH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VgCKUg22, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_x1rm3Kje, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FF93YLvV, 0.0f);
  numBytes += cVar_init_f(&cVar_YoP3VLL0, 1337.0f);
  numBytes += cVar_init_f(&cVar_7HOtjjir, 0.313f);
  numBytes += cBinop_init(&cBinop_GeGvr3Oe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pBvEOwqa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_34EZDMws, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TTgM7UXk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yQMnqrCN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cwv0n0nu, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_rMtWnQWK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_gGDqVmN3, 0.0f);
  numBytes += cVar_init_f(&cVar_Ulx1pPmJ, 1037.0f);
  numBytes += cVar_init_f(&cVar_w6ediJWL, 0.4f);
  numBytes += cBinop_init(&cBinop_nPIj9Dcu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_D8o8vYSV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vqi9OYZ4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wT4jc7UM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SfOQRH8Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FZD4qPxC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ISv0Xv5s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bYuNVGQS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1aLfzKoY, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_FWP0iEYy, 1, -1);
  numBytes += cVar_init_f(&cVar_0IK5MlJ1, 1337.0f);
  numBytes += cVar_init_f(&cVar_ZqmQOpJV, 0.0f);
  numBytes += cIf_init(&cIf_RpALQ8jY, false);
  numBytes += cIf_init(&cIf_LNSRre1K, false);
  numBytes += cBinop_init(&cBinop_mCIv7Iks, 0.0f); // __pow
  numBytes += cIf_init(&cIf_IYoN9fVT, false);
  numBytes += cBinop_init(&cBinop_Vs89tYpy, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_puNC4FeN, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_q4joiynj, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_QEatkrc1, 0.0f);
  numBytes += cIf_init(&cIf_XPURx8if, false);
  numBytes += cIf_init(&cIf_WMdSKUiE, false);
  numBytes += cBinop_init(&cBinop_6q73QilO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Zonuzs6J, false);
  numBytes += cBinop_init(&cBinop_gw0P60q4, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_lQFoxM23, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_MkZQpYY4, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_w8nnkKme, 0.0f);
  numBytes += cIf_init(&cIf_dJW328mW, false);
  numBytes += cIf_init(&cIf_R6nf4AoG, false);
  numBytes += cBinop_init(&cBinop_rLFpzuof, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6w0hz103, false);
  numBytes += cBinop_init(&cBinop_JAAOYYgq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Ziv4Szt7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_x8k89JlU, -15.0f); // __eq
  numBytes += cIf_init(&cIf_JRUSUJGN, false);
  numBytes += cSlice_init(&cSlice_HMLN4ATT, 1, -1);
  numBytes += cVar_init_f(&cVar_1dk98Dpa, 0.0f);
  numBytes += cSlice_init(&cSlice_uanfLJcN, 1, -1);
  numBytes += cVar_init_f(&cVar_2pSlo38w, 0.0f);
  numBytes += cSlice_init(&cSlice_0G5I1qhS, 1, -1);
  numBytes += cVar_init_f(&cVar_50C7UunF, 0.0f);
  numBytes += cSlice_init(&cSlice_M6LPjsmB, 1, -1);
  numBytes += cVar_init_f(&cVar_xAJlwTbP, 0.313f);
  numBytes += cBinop_init(&cBinop_Z0COrigM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_obsy7Te9, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_yTXa8iXA, 0.0f);
  numBytes += cVar_init_f(&cVar_tp4yvzUz, 1337.0f);
  numBytes += cVar_init_f(&cVar_eBvrwq5S, 0.3f);
  numBytes += cBinop_init(&cBinop_91t8vYkS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dEMOq3d7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XBpSyLyp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ildD80fG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JbCaoDyp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KVnqChNH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wCzrqQz8, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_NaxQzT4X, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_3StiYsDb, 0.0f);
  numBytes += cVar_init_f(&cVar_ql7d0i8F, 1337.0f);
  numBytes += cVar_init_f(&cVar_TNKRroM5, 0.313f);
  numBytes += cBinop_init(&cBinop_LCidfCYi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M2UJYIcO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_B73S8ozA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fQoUaQv8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2PHOlS2R, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_j0nSGI1W, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_eDRThMUM, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_f0rTCz3V, 0.0f);
  numBytes += cVar_init_f(&cVar_QnqRtE5l, 1037.0f);
  numBytes += cVar_init_f(&cVar_KCFupp6a, 0.4f);
  numBytes += cBinop_init(&cBinop_yfuYtUtN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0JQXe0Bz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TvfOVPPM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5fzPqa1J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cdU9ucsZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_A2xeNuaG, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_G0HKvdQW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FZo7Nmp8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nXoiuc1I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8TBYdQtc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_t0iHwBAU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DYdNKAJ7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_N7vnEvhw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ytfpN0UH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v2D4gYwK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MnJ8ysBm, 5705.6f);
  numBytes += cVar_init_f(&cVar_4B7YVJpz, 313.3f);
  numBytes += cBinop_init(&cBinop_cFeQCLO8, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_RltIj9Ib, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_EeFadROy, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HRdEwSMM_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UNlY3RdK_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8a5KIfN2_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nnl1b4QD_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9aWy91uk_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WG4AzsqV_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5Xn9UTQO_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RYHbJdQk_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TLXuO23e_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r0phQYrz_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j7Cy4it0_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9TVUUmEW_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fB2LZ6mg_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9gglx4Rx_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NjlkeTyi_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oKwmmp9l_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UnqFFYdI_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8PO9KVqw_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1tw84Dlh_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_taw2xMs4_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1s91C4ee_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CKcSLZe8_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sWOU9Ez1_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3WCaxAeb_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yYqxq99t_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rBq6vVHE_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HfKK8hg4_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TzZrkRss_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_InLDcuxa_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WRhUeBAN_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q7qnlNxl_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MbKvlRdI_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QxHIo4oY_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_jR6LQmDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z1eiylHT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_hu9t0ZGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TRyNOaxp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_p88jmWSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VA3ikGL4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_xWfxpODF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_toB5KbGL_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OmBJ9tDW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ygLO6LdH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DuHkqFR2_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_jMe3trYS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ERi54sF2, 0, m, &cSlice_ERi54sF2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QdDHarbo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ERi54sF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fJWOsytQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fJWOsytQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_6vgiU36F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fJWOsytQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_fJWOsytQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5Xn9UTQO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_iuV04dgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HeR1bPmb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_lPJ7Kac7, 0, m, &cIf_lPJ7Kac7_sendMessage);
}

void Heavy_WSTD_EQ::cIf_lPJ7Kac7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0SSKcOIO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_fdUramuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zegVO73N_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XeJdZjLM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_oFwntC99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5oP5Tcq, HV_BINOP_POW, 0, m, &cBinop_x5oP5Tcq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x5oP5Tcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0WXtZGcN, 0, m, &cIf_0WXtZGcN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Eo2a9mFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_UMhMemUl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VQJ20GeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fdUramuD, 0, m, &cIf_fdUramuD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ca2v5stC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wFoXDxnP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wFoXDxnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fdUramuD, 1, m, &cIf_fdUramuD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XeJdZjLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Eo2a9mFr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zegVO73N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0WXtZGcN, 0, m, &cIf_0WXtZGcN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UMhMemUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5oP5Tcq, HV_BINOP_POW, 1, m, &cBinop_x5oP5Tcq_sendMessage);
  cMsg_oFwntC99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_0WXtZGcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_ISv0Xv5s, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_HeR1bPmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lPJ7Kac7, 1, m, &cIf_lPJ7Kac7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0SSKcOIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_90nkjVhD, HV_BINOP_GREATER_THAN, 1, m, &cBinop_90nkjVhD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZpMWTA12, HV_BINOP_EQ, 1, m, &cBinop_ZpMWTA12_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FEiUNQuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_h6eZUqSd, HV_BINOP_ADD, 0, m, &cBinop_h6eZUqSd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h6eZUqSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ca2v5stC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VQJ20GeY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_90nkjVhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0WXtZGcN, 1, m, &cIf_0WXtZGcN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZpMWTA12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TJL35w12_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_TJL35w12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ISv0Xv5s, m);
}

void Heavy_WSTD_EQ::cCast_DT0cuwEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FEiUNQuv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_czY5lvAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h6eZUqSd, HV_BINOP_ADD, 1, m, &cBinop_h6eZUqSd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_90nkjVhD, HV_BINOP_GREATER_THAN, 0, m, &cBinop_90nkjVhD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZpMWTA12, HV_BINOP_EQ, 0, m, &cBinop_ZpMWTA12_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VkNX5Qzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iuV04dgX, 0, m, &cVar_iuV04dgX_sendMessage);
}

void Heavy_WSTD_EQ::cVar_EgniqhLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LCRpEFDm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_2GGOWwqC, 0, m, &cIf_2GGOWwqC_sendMessage);
}

void Heavy_WSTD_EQ::cIf_2GGOWwqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TRBOxw1L_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_nBcfh5JG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_8nSyddlv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_yF9xQhGK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_99vvawyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5LETKEco, HV_BINOP_POW, 0, m, &cBinop_5LETKEco_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5LETKEco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WLfERHja, 0, m, &cIf_WLfERHja_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xkREBcJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9CYmGT0y_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qJzKeJTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6Pd0VTA1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2rITz84s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nBcfh5JG, 0, m, &cIf_nBcfh5JG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6Pd0VTA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nBcfh5JG, 1, m, &cIf_nBcfh5JG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yF9xQhGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xkREBcJs_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8nSyddlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WLfERHja, 0, m, &cIf_WLfERHja_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9CYmGT0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5LETKEco, HV_BINOP_POW, 1, m, &cBinop_5LETKEco_sendMessage);
  cMsg_99vvawyK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_WLfERHja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vIG0tccS_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bep8WhSe_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_nwoTKLvi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_LCRpEFDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2GGOWwqC, 1, m, &cIf_2GGOWwqC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TRBOxw1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U7EyBLxR, HV_BINOP_GREATER_THAN, 1, m, &cBinop_U7EyBLxR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uOP8Psqa, HV_BINOP_EQ, 1, m, &cBinop_uOP8Psqa_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_W6bqHOQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_20IBNC3o, HV_BINOP_ADD, 0, m, &cBinop_20IBNC3o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_20IBNC3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qJzKeJTi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2rITz84s_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_U7EyBLxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WLfERHja, 1, m, &cIf_WLfERHja_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uOP8Psqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m2w8buie_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_m2w8buie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vIG0tccS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bep8WhSe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_nwoTKLvi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Y5Fzst1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EgniqhLy, 0, m, &cVar_EgniqhLy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KaHWgqpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W6bqHOQm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_K5mrCo3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20IBNC3o, HV_BINOP_ADD, 1, m, &cBinop_20IBNC3o_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_U7EyBLxR, HV_BINOP_GREATER_THAN, 0, m, &cBinop_U7EyBLxR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uOP8Psqa, HV_BINOP_EQ, 0, m, &cBinop_uOP8Psqa_sendMessage);
}

void Heavy_WSTD_EQ::cVar_l1YdJQyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xao0teKM_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_3Jnn7z04, 0, m, &cIf_3Jnn7z04_sendMessage);
}

void Heavy_WSTD_EQ::cIf_3Jnn7z04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JSVtnCmQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_XjXEMLXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZPldY6b4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_DMWqNfKq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_PIM7zKX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LhKrhh0q, HV_BINOP_POW, 0, m, &cBinop_LhKrhh0q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LhKrhh0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LlInUCa5, 0, m, &cIf_LlInUCa5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OVwfEezR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_zNqxwCq3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1YfnQNck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jXKFu0wG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JH0feovq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XjXEMLXB, 0, m, &cIf_XjXEMLXB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jXKFu0wG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XjXEMLXB, 1, m, &cIf_XjXEMLXB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DMWqNfKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_OVwfEezR_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZPldY6b4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LlInUCa5, 0, m, &cIf_LlInUCa5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zNqxwCq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LhKrhh0q, HV_BINOP_POW, 1, m, &cBinop_LhKrhh0q_sendMessage);
  cMsg_PIM7zKX5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_LlInUCa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_1aLfzKoY, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_xao0teKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Jnn7z04, 1, m, &cIf_3Jnn7z04_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JSVtnCmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5OpoNHE0, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5OpoNHE0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2fYog2CZ, HV_BINOP_EQ, 1, m, &cBinop_2fYog2CZ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9kVpxk3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_abA1T0pR, HV_BINOP_ADD, 0, m, &cBinop_abA1T0pR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_abA1T0pR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YfnQNck_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JH0feovq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5OpoNHE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LlInUCa5, 1, m, &cIf_LlInUCa5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2fYog2CZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yzNfbLYE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_yzNfbLYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1aLfzKoY, m);
}

void Heavy_WSTD_EQ::cCast_wOgnvWYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9kVpxk3U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_DwDrQdOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_abA1T0pR, HV_BINOP_ADD, 1, m, &cBinop_abA1T0pR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5OpoNHE0, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5OpoNHE0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2fYog2CZ, HV_BINOP_EQ, 0, m, &cBinop_2fYog2CZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zmmWZtXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l1YdJQyP, 0, m, &cVar_l1YdJQyP_sendMessage);
}

void Heavy_WSTD_EQ::cIf_QaYLtO2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_bYuNVGQS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_L1aPREyt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YZopBRiX, 0, m, &cSlice_YZopBRiX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xinHSdLg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_YZopBRiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pKakZAaj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pKakZAaj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_rMxbk7XD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pKakZAaj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_pKakZAaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9aWy91uk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_xinHSdLg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7ss6mrIB, 0, m, &cSlice_7ss6mrIB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jMe3trYS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_7ss6mrIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lHYpxuUr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lHYpxuUr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_1PZOpDU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lHYpxuUr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_lHYpxuUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TLXuO23e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_QdDHarbo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qEmVEvW0, 0, m, &cSlice_qEmVEvW0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NlzNdXmr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_qEmVEvW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2ojauJzE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2ojauJzE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_55a9xp0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2ojauJzE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_2ojauJzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WG4AzsqV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_NlzNdXmr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5vCxgmwE, 0, m, &cSlice_5vCxgmwE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_5vCxgmwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yITf7A2J_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yITf7A2J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_b2N2KHSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yITf7A2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_yITf7A2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RYHbJdQk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_jJRHvzPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O3nHn3Ms, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_3O8s4U8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0SOisfAi, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_2kNFbonx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zSDPAtTR, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Zy98sRBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TkpjTkU4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_DkxTyfCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2YFvEdlw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_btJbAtDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aB2scd2z_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_aB2scd2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bmHrMCp8, HV_BINOP_DIVIDE, 1, m, &cBinop_bmHrMCp8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o5yu32N1_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_SYArllNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ZaSJWya3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wtyvcLMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_SYArllNB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZaSJWya3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bmHrMCp8, HV_BINOP_DIVIDE, 0, m, &cBinop_bmHrMCp8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o5yu32N1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wtyvcLMj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bmHrMCp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mfCl0EhF, HV_BINOP_MULTIPLY, 1, m, &cBinop_mfCl0EhF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mfCl0EhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lan8SMZ7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zxbMburV_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_qckoaVTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UITEr5la_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_N595kDHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_r3uJKQLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rgihVOij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_iKXf0yGB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iKXf0yGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mfCl0EhF, HV_BINOP_MULTIPLY, 0, m, &cBinop_mfCl0EhF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Yvq8eZeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_TyNCMZnK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TyNCMZnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dpzmWhHc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xZModIXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RA9Fh9N0, 1, m, &cVar_RA9Fh9N0_sendMessage);
}

void Heavy_WSTD_EQ::cVar_RA9Fh9N0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wynb2sPR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oL40cZol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jb8UW9YJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jb8UW9YJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bvdoFroT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oL40cZol_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XHza8N0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8gnVN4Bb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8gnVN4Bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CphboQjS, HV_BINOP_MULTIPLY, 1, m, &cBinop_CphboQjS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jVXWZIna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kSw4Kqyb, HV_BINOP_MULTIPLY, 1, m, &cBinop_kSw4Kqyb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ALeprX6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jVXWZIna_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Xsr3cgXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7YhuaILb, HV_BINOP_MULTIPLY, 1, m, &cBinop_7YhuaILb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_aU3FETo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_v0yr9H2b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v0yr9H2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uWxTS6aH, HV_BINOP_MULTIPLY, 1, m, &cBinop_uWxTS6aH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_XjpF1nK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gz4VxL0o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_rgihVOij_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uMmR7NZ8_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lfGKn0et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Yvq8eZeX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Lan8SMZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qckoaVTe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zxbMburV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_N595kDHZ_sendMessage);
}

void Heavy_WSTD_EQ::cSend_UITEr5la_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9TVUUmEW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_r3uJKQLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_j7Cy4it0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VP0hn1LK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r0phQYrz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dpzmWhHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_A4sZQ81G_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_A4sZQ81G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_llvTrYCS, HV_BINOP_MULTIPLY, 1, m, &cBinop_llvTrYCS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_llvTrYCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iD8iNreS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iD8iNreS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VP0hn1LK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_wynb2sPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TpuJKk89_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TpuJKk89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YOeXW8SO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mJO7KPRT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zdF3mwZ0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sPo3HTwf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9mUa5o8Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o8r9z7Nc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Jb8UW9YJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jJRHvzPt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_CphboQjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3O8s4U8d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_kSw4Kqyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2kNFbonx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7YhuaILb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zy98sRBQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uWxTS6aH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DkxTyfCO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_xfUzDyWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XjpF1nK9, 0, m, &cVar_XjpF1nK9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7nGpbSjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lfGKn0et, 1, m, &cVar_lfGKn0et_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zdF3mwZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7YhuaILb, HV_BINOP_MULTIPLY, 0, m, &cBinop_7YhuaILb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sPo3HTwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kSw4Kqyb, HV_BINOP_MULTIPLY, 0, m, &cBinop_kSw4Kqyb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o8r9z7Nc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jb8UW9YJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jb8UW9YJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YOeXW8SO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_9mUa5o8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CphboQjS, HV_BINOP_MULTIPLY, 0, m, &cBinop_CphboQjS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mJO7KPRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uWxTS6aH, HV_BINOP_MULTIPLY, 0, m, &cBinop_uWxTS6aH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uMmR7NZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RA9Fh9N0, 0, m, &cVar_RA9Fh9N0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gz4VxL0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lfGKn0et, 0, m, &cVar_lfGKn0et_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_iIWDKJ2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RX9Rt7V5, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qiWbflH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pdTALLqu, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_htwxsHyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Me4kh6A0, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_5pOgQrmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gjCJSX0T, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Jp0M7GgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mv8MZ5B0_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_mv8MZ5B0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VgCKUg22, HV_BINOP_DIVIDE, 1, m, &cBinop_VgCKUg22_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wyU8Ut2x_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_lClskFiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_jOwb2sQQ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_4I0oJCf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lClskFiu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jOwb2sQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VgCKUg22, HV_BINOP_DIVIDE, 0, m, &cBinop_VgCKUg22_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wyU8Ut2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4I0oJCf8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_VgCKUg22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x1rm3Kje, HV_BINOP_MULTIPLY, 1, m, &cBinop_x1rm3Kje_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x1rm3Kje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uCDlZRhl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yavpGOC2_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ZbR07Bft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WesxUaeA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_3LERnXib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SI5N3hq1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_sahk3t7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ZI6hp5mZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZI6hp5mZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x1rm3Kje, HV_BINOP_MULTIPLY, 0, m, &cBinop_x1rm3Kje_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_04xC21w4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dkBi7ju3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dkBi7ju3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R4OYTaR9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_YLVtW7Ha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_34EZDMws, HV_BINOP_MULTIPLY, 1, m, &cBinop_34EZDMws_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TZjWWy8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FF93YLvV, 1, m, &cVar_FF93YLvV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ckBCvs43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TTgM7UXk, HV_BINOP_MULTIPLY, 1, m, &cBinop_TTgM7UXk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZPoEER9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Asrtl6pg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Asrtl6pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQMnqrCN, HV_BINOP_MULTIPLY, 1, m, &cBinop_yQMnqrCN_sendMessage);
}

void Heavy_WSTD_EQ::cVar_FF93YLvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TYIrvyDZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_YoP3VLL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fnIHUo2R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_sahk3t7d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tiaOt0mN_sendMessage);
}

void Heavy_WSTD_EQ::cVar_7HOtjjir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_04xC21w4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uCDlZRhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ZbR07Bft_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yavpGOC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3LERnXib_sendMessage);
}

void Heavy_WSTD_EQ::cSend_WesxUaeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NjlkeTyi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_SI5N3hq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9gglx4Rx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_vLRV1MB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fB2LZ6mg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_R4OYTaR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aOmIofQo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aOmIofQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GeGvr3Oe, HV_BINOP_MULTIPLY, 1, m, &cBinop_GeGvr3Oe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GeGvr3Oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xSkHqZqI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xSkHqZqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vLRV1MB5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_TYIrvyDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_y2NbB2kU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_y2NbB2kU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f6QlNeMH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0uwKIF9L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HXQYMQq7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YmvNFQO4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pBvEOwqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iIWDKJ2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_34EZDMws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qiWbflH9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_TTgM7UXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_htwxsHyB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yQMnqrCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5pOgQrmw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Twjbn1nc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7HOtjjir, 1, m, &cVar_7HOtjjir_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CzihH7D2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YoP3VLL0, 0, m, &cVar_YoP3VLL0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tiaOt0mN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FF93YLvV, 0, m, &cVar_FF93YLvV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fnIHUo2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7HOtjjir, 0, m, &cVar_7HOtjjir_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HXQYMQq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_34EZDMws, HV_BINOP_MULTIPLY, 0, m, &cBinop_34EZDMws_sendMessage);
}

void Heavy_WSTD_EQ::cCast_f6QlNeMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQMnqrCN, HV_BINOP_MULTIPLY, 0, m, &cBinop_yQMnqrCN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YmvNFQO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pBvEOwqa, HV_BINOP_MULTIPLY, 0, m, &cBinop_pBvEOwqa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0uwKIF9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TTgM7UXk, HV_BINOP_MULTIPLY, 0, m, &cBinop_TTgM7UXk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Dsd4AXJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QivctcJm, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_gIXij6tD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xhXTdJxB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hcPKx5pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ySQuIKOt, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_O9hqzuHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sGVFRZuB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_5vhsAUJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5zYAF9uX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_LHrffh6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_djdRhhql_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_djdRhhql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cwv0n0nu, HV_BINOP_DIVIDE, 1, m, &cBinop_cwv0n0nu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i0BuyQBu_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_DrsnxyyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_v6rcBUre_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_c3rnbLM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_DrsnxyyL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v6rcBUre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cwv0n0nu, HV_BINOP_DIVIDE, 0, m, &cBinop_cwv0n0nu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_i0BuyQBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c3rnbLM6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_cwv0n0nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rMtWnQWK, HV_BINOP_MULTIPLY, 1, m, &cBinop_rMtWnQWK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rMtWnQWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cz5yvuwF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OYMzjbHP_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_IatBf0HT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_H78OVDsC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_EIVvwYPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IA8MjLTp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IVBqHn9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_wdAOnEZ3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wdAOnEZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rMtWnQWK, HV_BINOP_MULTIPLY, 0, m, &cBinop_rMtWnQWK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lFpu7gee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_U6IfNF2n_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_U6IfNF2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NibO8FRQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_TpYJj7Zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D8o8vYSV, HV_BINOP_MULTIPLY, 1, m, &cBinop_D8o8vYSV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_g04HkIix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KJTFX6hd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KJTFX6hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TpYJj7Zr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Kq8cJ5AJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_m3B4Lts4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m3B4Lts4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vqi9OYZ4, HV_BINOP_MULTIPLY, 1, m, &cBinop_vqi9OYZ4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_w0H6Eo8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wT4jc7UM, HV_BINOP_MULTIPLY, 1, m, &cBinop_wT4jc7UM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_yMElY95W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5gWSfsSu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5gWSfsSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_w0H6Eo8k_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_G2yq7spQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gGDqVmN3, 1, m, &cVar_gGDqVmN3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_32PNfbFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SfOQRH8Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_SfOQRH8Y_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_sic9MGN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Oqr0ePaQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Oqr0ePaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FZD4qPxC, HV_BINOP_MULTIPLY, 1, m, &cBinop_FZD4qPxC_sendMessage);
}

void Heavy_WSTD_EQ::cVar_gGDqVmN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kJgpmTmv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Ulx1pPmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qtQ5UvIq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IVBqHn9D_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5IMcpYja_sendMessage);
}

void Heavy_WSTD_EQ::cVar_w6ediJWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lFpu7gee_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OYMzjbHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_EIVvwYPb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cz5yvuwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_IatBf0HT_sendMessage);
}

void Heavy_WSTD_EQ::cSend_H78OVDsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8PO9KVqw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_IA8MjLTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UnqFFYdI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bxlpCBBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oKwmmp9l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_NibO8FRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_irICAiZn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_irICAiZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nPIj9Dcu, HV_BINOP_MULTIPLY, 1, m, &cBinop_nPIj9Dcu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nPIj9Dcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sQiGHKCj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sQiGHKCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bxlpCBBC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_kJgpmTmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NtJSDvqB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NtJSDvqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZgJGFVJb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uNyqayhg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6FReg2H4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PrfnKxOW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NG0eM9PC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eWxEaXKp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_D8o8vYSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dsd4AXJr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vqi9OYZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gIXij6tD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wT4jc7UM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hcPKx5pw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_SfOQRH8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O9hqzuHd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FZD4qPxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5vhsAUJq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_EIP8BsFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w6ediJWL, 1, m, &cVar_w6ediJWL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Inni5gCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ulx1pPmJ, 0, m, &cVar_Ulx1pPmJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NG0eM9PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vqi9OYZ4, HV_BINOP_MULTIPLY, 0, m, &cBinop_vqi9OYZ4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZgJGFVJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_eWxEaXKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D8o8vYSV, HV_BINOP_MULTIPLY, 0, m, &cBinop_D8o8vYSV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6FReg2H4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SfOQRH8Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_SfOQRH8Y_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PrfnKxOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wT4jc7UM, HV_BINOP_MULTIPLY, 0, m, &cBinop_wT4jc7UM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uNyqayhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FZD4qPxC, HV_BINOP_MULTIPLY, 0, m, &cBinop_FZD4qPxC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qtQ5UvIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w6ediJWL, 0, m, &cVar_w6ediJWL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5IMcpYja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gGDqVmN3, 0, m, &cVar_gGDqVmN3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vIG0tccS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaYLtO2n, 1, m, &cIf_QaYLtO2n_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vjERy8sP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bYuNVGQS, m);
}

void Heavy_WSTD_EQ::cBinop_bep8WhSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vjERy8sP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nwoTKLvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaYLtO2n, 0, m, &cIf_QaYLtO2n_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_Cl32bYkC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FWP0iEYy, 0, m, &cSlice_FWP0iEYy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6yDgWTSU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_FWP0iEYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yz2uC2hW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yz2uC2hW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_0IK5MlJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yz2uC2hW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_yz2uC2hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1s91C4ee_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ZqmQOpJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oDNV8GWW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_RpALQ8jY, 0, m, &cIf_RpALQ8jY_sendMessage);
}

void Heavy_WSTD_EQ::cIf_RpALQ8jY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Zx0FPTFy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_LNSRre1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JmuLZ6F5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_OJDkIi0m_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_WMWGkGfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mCIv7Iks, HV_BINOP_POW, 0, m, &cBinop_mCIv7Iks_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mCIv7Iks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IYoN9fVT, 0, m, &cIf_IYoN9fVT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6SfOWZaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_G5s79VTr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NSPThJkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_psOl43Xs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RURlEkzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LNSRre1K, 0, m, &cIf_LNSRre1K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_psOl43Xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LNSRre1K, 1, m, &cIf_LNSRre1K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OJDkIi0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6SfOWZaL_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JmuLZ6F5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_IYoN9fVT, 0, m, &cIf_IYoN9fVT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_G5s79VTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mCIv7Iks, HV_BINOP_POW, 1, m, &cBinop_mCIv7Iks_sendMessage);
  cMsg_WMWGkGfy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_IYoN9fVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_G0HKvdQW, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_oDNV8GWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RpALQ8jY, 1, m, &cIf_RpALQ8jY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Zx0FPTFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_puNC4FeN, HV_BINOP_GREATER_THAN, 1, m, &cBinop_puNC4FeN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q4joiynj, HV_BINOP_EQ, 1, m, &cBinop_q4joiynj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_btoZ6iI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vs89tYpy, HV_BINOP_ADD, 0, m, &cBinop_Vs89tYpy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Vs89tYpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NSPThJkc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RURlEkzm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_puNC4FeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IYoN9fVT, 1, m, &cIf_IYoN9fVT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q4joiynj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TfFb5AcR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_TfFb5AcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_G0HKvdQW, m);
}

void Heavy_WSTD_EQ::cCast_hMo3Cpaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vs89tYpy, HV_BINOP_ADD, 1, m, &cBinop_Vs89tYpy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_puNC4FeN, HV_BINOP_GREATER_THAN, 0, m, &cBinop_puNC4FeN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q4joiynj, HV_BINOP_EQ, 0, m, &cBinop_q4joiynj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ui2d4TXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZqmQOpJV, 0, m, &cVar_ZqmQOpJV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1isjUBzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_btoZ6iI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_QEatkrc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xRvaK9Hb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_XPURx8if, 0, m, &cIf_XPURx8if_sendMessage);
}

void Heavy_WSTD_EQ::cIf_XPURx8if_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_luShR2qb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_WMdSKUiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_k0AoZSGU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_UTTnzL3g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_YMowjVSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6q73QilO, HV_BINOP_POW, 0, m, &cBinop_6q73QilO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6q73QilO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zonuzs6J, 0, m, &cIf_Zonuzs6J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gT5F86mE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_bpc2iY9X_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iwXQCphQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WMdSKUiE, 0, m, &cIf_WMdSKUiE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_faiOkuYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RxNPvtev_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RxNPvtev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WMdSKUiE, 1, m, &cIf_WMdSKUiE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UTTnzL3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gT5F86mE_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_k0AoZSGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Zonuzs6J, 0, m, &cIf_Zonuzs6J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bpc2iY9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6q73QilO, HV_BINOP_POW, 1, m, &cBinop_6q73QilO_sendMessage);
  cMsg_YMowjVSx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_Zonuzs6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iWt2Mw6E_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GQat40Fi_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_GjOa92Wc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_xRvaK9Hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XPURx8if, 1, m, &cIf_XPURx8if_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_luShR2qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lQFoxM23, HV_BINOP_GREATER_THAN, 1, m, &cBinop_lQFoxM23_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MkZQpYY4, HV_BINOP_EQ, 1, m, &cBinop_MkZQpYY4_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MVG8y84I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gw0P60q4, HV_BINOP_ADD, 0, m, &cBinop_gw0P60q4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gw0P60q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_faiOkuYL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iwXQCphQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lQFoxM23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zonuzs6J, 1, m, &cIf_Zonuzs6J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MkZQpYY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kAk2nDg2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_kAk2nDg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iWt2Mw6E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GQat40Fi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_GjOa92Wc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_E6QbITAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QEatkrc1, 0, m, &cVar_QEatkrc1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6v6NVf5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MVG8y84I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_OPV44hOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gw0P60q4, HV_BINOP_ADD, 1, m, &cBinop_gw0P60q4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lQFoxM23, HV_BINOP_GREATER_THAN, 0, m, &cBinop_lQFoxM23_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MkZQpYY4, HV_BINOP_EQ, 0, m, &cBinop_MkZQpYY4_sendMessage);
}

void Heavy_WSTD_EQ::cVar_w8nnkKme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xoftbGwU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dJW328mW, 0, m, &cIf_dJW328mW_sendMessage);
}

void Heavy_WSTD_EQ::cIf_dJW328mW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cVRakZw1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_R6nf4AoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_XwFxRTsy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tIYQ1Lqn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_fVaGwnWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rLFpzuof, HV_BINOP_POW, 0, m, &cBinop_rLFpzuof_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rLFpzuof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6w0hz103, 0, m, &cIf_6w0hz103_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gvMEXQAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_mgrad0kc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_p6ysQsMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aFGC6t5i_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gGelR6qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R6nf4AoG, 0, m, &cIf_R6nf4AoG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aFGC6t5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R6nf4AoG, 1, m, &cIf_R6nf4AoG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tIYQ1Lqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gvMEXQAU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XwFxRTsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6w0hz103, 0, m, &cIf_6w0hz103_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mgrad0kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rLFpzuof, HV_BINOP_POW, 1, m, &cBinop_rLFpzuof_sendMessage);
  cMsg_fVaGwnWY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_6w0hz103_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_nXoiuc1I, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_xoftbGwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dJW328mW, 1, m, &cIf_dJW328mW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cVRakZw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ziv4Szt7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Ziv4Szt7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x8k89JlU, HV_BINOP_EQ, 1, m, &cBinop_x8k89JlU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9aqTDCgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JAAOYYgq, HV_BINOP_ADD, 0, m, &cBinop_JAAOYYgq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JAAOYYgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p6ysQsMk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gGelR6qt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ziv4Szt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6w0hz103, 1, m, &cIf_6w0hz103_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x8k89JlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wVguzM5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_wVguzM5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nXoiuc1I, m);
}

void Heavy_WSTD_EQ::cCast_IXpwXYPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JAAOYYgq, HV_BINOP_ADD, 1, m, &cBinop_JAAOYYgq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ziv4Szt7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Ziv4Szt7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x8k89JlU, HV_BINOP_EQ, 0, m, &cBinop_x8k89JlU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yqbmjXMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w8nnkKme, 0, m, &cVar_w8nnkKme_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QQIEPmwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9aqTDCgl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_JRUSUJGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_FZo7Nmp8, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_Nreagtbb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HMLN4ATT, 0, m, &cSlice_HMLN4ATT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WbHIBVvW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_HMLN4ATT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gtIus0jM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gtIus0jM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_1dk98Dpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gtIus0jM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_gtIus0jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1tw84Dlh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_WbHIBVvW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uanfLJcN, 0, m, &cSlice_uanfLJcN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Cl32bYkC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_uanfLJcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3zMlfUGN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3zMlfUGN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_2pSlo38w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3zMlfUGN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_3zMlfUGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sWOU9Ez1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_6yDgWTSU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0G5I1qhS, 0, m, &cSlice_0G5I1qhS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_spdKu6hp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_0G5I1qhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tPCHAaP1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tPCHAaP1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_50C7UunF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tPCHAaP1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_tPCHAaP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_taw2xMs4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_spdKu6hp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M6LPjsmB, 0, m, &cSlice_M6LPjsmB_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_M6LPjsmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FOq02q3G_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FOq02q3G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_xAJlwTbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FOq02q3G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_FOq02q3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CKcSLZe8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_4cF3qelY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JbsYuMyX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_MC8k9bWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KJnRgbRc, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_1tk6yV5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AIFRgkeT, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EWvj0bJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LpgV3paW, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_WU1vx70S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UAdmxef8, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_xWIhQTCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_F2Z2xAT6_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_F2Z2xAT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z0COrigM, HV_BINOP_DIVIDE, 1, m, &cBinop_Z0COrigM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tWVvvT1k_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_fNs6VT8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_daHJgWdV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6kQiK3aN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_fNs6VT8f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_daHJgWdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z0COrigM, HV_BINOP_DIVIDE, 0, m, &cBinop_Z0COrigM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tWVvvT1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6kQiK3aN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Z0COrigM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obsy7Te9, HV_BINOP_MULTIPLY, 1, m, &cBinop_obsy7Te9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_obsy7Te9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OuAKee01_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yLEOdl0r_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_nrOiDEvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pttSUdtu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_uVWAf7V2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lKfJ5D9U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_COPNTlpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_tFazhFF4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tFazhFF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obsy7Te9, HV_BINOP_MULTIPLY, 0, m, &cBinop_obsy7Te9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ozuVIZuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_tGxyRxDY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tGxyRxDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YNTCLpYf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_cecNrKIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yTXa8iXA, 1, m, &cVar_yTXa8iXA_sendMessage);
}

void Heavy_WSTD_EQ::cVar_yTXa8iXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AJ2MVVDh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qDYyfZ6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEMOq3d7, HV_BINOP_MULTIPLY, 1, m, &cBinop_dEMOq3d7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0hy5AUAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qDYyfZ6E_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V0GfTFuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YoqATDUs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YoqATDUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XBpSyLyp, HV_BINOP_MULTIPLY, 1, m, &cBinop_XBpSyLyp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tcHhN8Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ildD80fG, HV_BINOP_MULTIPLY, 1, m, &cBinop_ildD80fG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mUoEMsPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tcHhN8Bu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DrOsq9if_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JbCaoDyp, HV_BINOP_MULTIPLY, 1, m, &cBinop_JbCaoDyp_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XrApD5RB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hlsgpU9g_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hlsgpU9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KVnqChNH, HV_BINOP_MULTIPLY, 1, m, &cBinop_KVnqChNH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_tp4yvzUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TzCvoDVm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_COPNTlpk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g5c9QAYf_sendMessage);
}

void Heavy_WSTD_EQ::cVar_eBvrwq5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ozuVIZuI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yLEOdl0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_uVWAf7V2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OuAKee01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_nrOiDEvZ_sendMessage);
}

void Heavy_WSTD_EQ::cSend_pttSUdtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rBq6vVHE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_lKfJ5D9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yYqxq99t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_DK1A7EFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3WCaxAeb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_YNTCLpYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_paJobGg6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_paJobGg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_91t8vYkS, HV_BINOP_MULTIPLY, 1, m, &cBinop_91t8vYkS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_91t8vYkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sWIawRMz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sWIawRMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DK1A7EFh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_AJ2MVVDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9utTVBYu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9utTVBYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y94VP0k1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2p5cDElN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kB3xPzvF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nQxcZ738_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nWDWoNvS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EaRNhXJT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dEMOq3d7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4cF3qelY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XBpSyLyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MC8k9bWL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ildD80fG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1tk6yV5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JbCaoDyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EWvj0bJr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KVnqChNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WU1vx70S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_LobJ3X5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tp4yvzUz, 0, m, &cVar_tp4yvzUz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gzReOKe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eBvrwq5S, 1, m, &cVar_eBvrwq5S_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2p5cDElN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KVnqChNH, HV_BINOP_MULTIPLY, 0, m, &cBinop_KVnqChNH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kB3xPzvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JbCaoDyp, HV_BINOP_MULTIPLY, 0, m, &cBinop_JbCaoDyp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nQxcZ738_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ildD80fG, HV_BINOP_MULTIPLY, 0, m, &cBinop_ildD80fG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EaRNhXJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEMOq3d7, HV_BINOP_MULTIPLY, 0, m, &cBinop_dEMOq3d7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_y94VP0k1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_nWDWoNvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XBpSyLyp, HV_BINOP_MULTIPLY, 0, m, &cBinop_XBpSyLyp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_g5c9QAYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yTXa8iXA, 0, m, &cVar_yTXa8iXA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TzCvoDVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eBvrwq5S, 0, m, &cVar_eBvrwq5S_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GrnG1vwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XU7zAlrO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jLblHj73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tzoZym8h, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_rUovXJRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8zxoC1ga, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jF84ml8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pubH4jLX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_F6ccr0Jw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_At431eKk_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_At431eKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wCzrqQz8, HV_BINOP_DIVIDE, 1, m, &cBinop_wCzrqQz8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NkU0Y2Jm_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_0KPURpHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GXS8Tmsx_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_51jHOGjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_0KPURpHT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GXS8Tmsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wCzrqQz8, HV_BINOP_DIVIDE, 0, m, &cBinop_wCzrqQz8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NkU0Y2Jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_51jHOGjX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wCzrqQz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NaxQzT4X, HV_BINOP_MULTIPLY, 1, m, &cBinop_NaxQzT4X_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NaxQzT4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_izB781Ra_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gSJKAbAw_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_U16zFDr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9XPO4fgA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_9KDwIqIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QixQkigC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_50sdpWae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_1YAEtSVh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1YAEtSVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NaxQzT4X, HV_BINOP_MULTIPLY, 0, m, &cBinop_NaxQzT4X_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oTgCEmjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_RFwNwJEy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RFwNwJEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mNwnbx21_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DU40Dnqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B73S8ozA, HV_BINOP_MULTIPLY, 1, m, &cBinop_B73S8ozA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DCR8YCB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3StiYsDb, 1, m, &cVar_3StiYsDb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rUqIZhED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fQoUaQv8, HV_BINOP_MULTIPLY, 1, m, &cBinop_fQoUaQv8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JvOGHvMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KP830iDL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KP830iDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2PHOlS2R, HV_BINOP_MULTIPLY, 1, m, &cBinop_2PHOlS2R_sendMessage);
}

void Heavy_WSTD_EQ::cVar_3StiYsDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_btmPMSfb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ql7d0i8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ILCVdDST_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_50sdpWae_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AhFqmirS_sendMessage);
}

void Heavy_WSTD_EQ::cVar_TNKRroM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oTgCEmjh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_izB781Ra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_U16zFDr6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gSJKAbAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9KDwIqIy_sendMessage);
}

void Heavy_WSTD_EQ::cSend_9XPO4fgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_InLDcuxa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_QixQkigC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TzZrkRss_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_2GoUAYwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HfKK8hg4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_mNwnbx21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6Q9DYceq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6Q9DYceq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LCidfCYi, HV_BINOP_MULTIPLY, 1, m, &cBinop_LCidfCYi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LCidfCYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WsI9LPjb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WsI9LPjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2GoUAYwm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_btmPMSfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NvPHAuaN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NvPHAuaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9CCxDimO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0XFmKodN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RDxFOAmR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kv97UwZd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M2UJYIcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GrnG1vwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_B73S8ozA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jLblHj73_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_fQoUaQv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rUovXJRt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_2PHOlS2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jF84ml8r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_b9YnVRl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ql7d0i8F, 0, m, &cVar_ql7d0i8F_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lnUYSSvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TNKRroM5, 1, m, &cVar_TNKRroM5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AhFqmirS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3StiYsDb, 0, m, &cVar_3StiYsDb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ILCVdDST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TNKRroM5, 0, m, &cVar_TNKRroM5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9CCxDimO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2PHOlS2R, HV_BINOP_MULTIPLY, 0, m, &cBinop_2PHOlS2R_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Kv97UwZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M2UJYIcO, HV_BINOP_MULTIPLY, 0, m, &cBinop_M2UJYIcO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0XFmKodN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fQoUaQv8, HV_BINOP_MULTIPLY, 0, m, &cBinop_fQoUaQv8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RDxFOAmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B73S8ozA, HV_BINOP_MULTIPLY, 0, m, &cBinop_B73S8ozA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ONMaV3sP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pwDN8aVu, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_2u5UgRTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vXPSzXpM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_QGnB0eKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vQPXzreO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_1qtFdHIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sSudC3EV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_DkhhdKU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T18fqQ5A, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9jWLgafD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OTYSqysp_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_OTYSqysp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j0nSGI1W, HV_BINOP_DIVIDE, 1, m, &cBinop_j0nSGI1W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pprr5pwS_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_W6XchiOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_sgVBsRdE_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_5UuLqYlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_W6XchiOQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sgVBsRdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j0nSGI1W, HV_BINOP_DIVIDE, 0, m, &cBinop_j0nSGI1W_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Pprr5pwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5UuLqYlm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_j0nSGI1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eDRThMUM, HV_BINOP_MULTIPLY, 1, m, &cBinop_eDRThMUM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eDRThMUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k4p1AFXp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uI4qDCK3_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_5tnD4FJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bOqQA5tP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_WHg3Dain_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ILKp9Ong_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_z0hT8cj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_VXXsLlSK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VXXsLlSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eDRThMUM, HV_BINOP_MULTIPLY, 0, m, &cBinop_eDRThMUM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oetYKDMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_K46YAeaA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_K46YAeaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6k62MvVq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_e2PZLl46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0JQXe0Bz, HV_BINOP_MULTIPLY, 1, m, &cBinop_0JQXe0Bz_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SkxIGYi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mgcC479C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mgcC479C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_e2PZLl46_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_m4PGFqS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Uwq7W8Qx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Uwq7W8Qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvfOVPPM, HV_BINOP_MULTIPLY, 1, m, &cBinop_TvfOVPPM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OAbZAhQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5fzPqa1J, HV_BINOP_MULTIPLY, 1, m, &cBinop_5fzPqa1J_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_A0mo9PiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tE3J0Glt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tE3J0Glt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OAbZAhQT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_U1yqhbTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f0rTCz3V, 1, m, &cVar_f0rTCz3V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F60IAv83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cdU9ucsZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_cdU9ucsZ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_BUXUgl2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KGc3JtQx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KGc3JtQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A2xeNuaG, HV_BINOP_MULTIPLY, 1, m, &cBinop_A2xeNuaG_sendMessage);
}

void Heavy_WSTD_EQ::cVar_f0rTCz3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o6x3p4jH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_QnqRtE5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u4dx4QM1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_z0hT8cj1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_minTaZuD_sendMessage);
}

void Heavy_WSTD_EQ::cVar_KCFupp6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oetYKDMq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_k4p1AFXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5tnD4FJN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uI4qDCK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_WHg3Dain_sendMessage);
}

void Heavy_WSTD_EQ::cSend_bOqQA5tP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MbKvlRdI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ILKp9Ong_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q7qnlNxl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_pK4bhkr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WRhUeBAN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6k62MvVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7GBZQahs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7GBZQahs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yfuYtUtN, HV_BINOP_MULTIPLY, 1, m, &cBinop_yfuYtUtN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yfuYtUtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0RHyMLa0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0RHyMLa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pK4bhkr3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_o6x3p4jH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zoxisabz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zoxisabz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iBTXr2p7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M8skO7Wx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UQJMwYZQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oWycLqqH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EkFhDmiA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LNtOxSEH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0JQXe0Bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ONMaV3sP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_TvfOVPPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2u5UgRTy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5fzPqa1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QGnB0eKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_cdU9ucsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1qtFdHIz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_A2xeNuaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DkhhdKU8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_W0VmsakG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KCFupp6a, 1, m, &cVar_KCFupp6a_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uVAxifez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QnqRtE5l, 0, m, &cVar_QnqRtE5l_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EkFhDmiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvfOVPPM, HV_BINOP_MULTIPLY, 0, m, &cBinop_TvfOVPPM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UQJMwYZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cdU9ucsZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_cdU9ucsZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oWycLqqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5fzPqa1J, HV_BINOP_MULTIPLY, 0, m, &cBinop_5fzPqa1J_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LNtOxSEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0JQXe0Bz, HV_BINOP_MULTIPLY, 0, m, &cBinop_0JQXe0Bz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iBTXr2p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_M8skO7Wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A2xeNuaG, HV_BINOP_MULTIPLY, 0, m, &cBinop_A2xeNuaG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_u4dx4QM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KCFupp6a, 0, m, &cVar_KCFupp6a_sendMessage);
}

void Heavy_WSTD_EQ::cCast_minTaZuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f0rTCz3V, 0, m, &cVar_f0rTCz3V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iWt2Mw6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JRUSUJGN, 1, m, &cIf_JRUSUJGN_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_C8MDlGJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FZo7Nmp8, m);
}

void Heavy_WSTD_EQ::cBinop_GQat40Fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C8MDlGJL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GjOa92Wc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JRUSUJGN, 0, m, &cIf_JRUSUJGN_sendMessage);
}

void Heavy_WSTD_EQ::cVar_MnJ8ysBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RltIj9Ib, HV_BINOP_DIVIDE, 0, m, &cBinop_RltIj9Ib_sendMessage);
}

void Heavy_WSTD_EQ::cVar_4B7YVJpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cFeQCLO8, HV_BINOP_DIVIDE, 1, m, &cBinop_cFeQCLO8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RltIj9Ib, HV_BINOP_DIVIDE, 1, m, &cBinop_RltIj9Ib_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_PdSSrYJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EeFadROy, HV_BINOP_DIVIDE, 0, m, &cBinop_EeFadROy_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_eci1TIgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EeFadROy, HV_BINOP_DIVIDE, 1, m, &cBinop_EeFadROy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ygLO6LdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MnJ8ysBm, 0, m, &cVar_MnJ8ysBm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OmBJ9tDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4B7YVJpz, 0, m, &cVar_4B7YVJpz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DuHkqFR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cFeQCLO8, HV_BINOP_DIVIDE, 0, m, &cBinop_cFeQCLO8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cFeQCLO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_PdSSrYJR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RltIj9Ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_eci1TIgQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EeFadROy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_xvBrlnR7_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_h9FGWrYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_eEpK9I0Z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O4vf01CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_iUyvtZAt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xvBrlnR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_O4vf01CX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iUyvtZAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_h9FGWrYj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eEpK9I0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q4fIRepv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_z1eiylHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L1aPREyt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Nreagtbb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_TRyNOaxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L1aPREyt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Nreagtbb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_VA3ikGL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L1aPREyt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Nreagtbb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_toB5KbGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L1aPREyt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Nreagtbb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_q4fIRepv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L1aPREyt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Nreagtbb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_z8sqZFu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_xWfxpODF, 0, m, &cVar_xWfxpODF_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Tta34mmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_jR6LQmDP, 0, m, &cVar_jR6LQmDP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hu9t0ZGE, 0, m, &cVar_hu9t0ZGE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_p88jmWSr, 0, m, &cVar_p88jmWSr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_HRdEwSMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jR6LQmDP, 0, m, &cVar_jR6LQmDP_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_8a5KIfN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hu9t0ZGE, 0, m, &cVar_hu9t0ZGE_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_UNlY3RdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p88jmWSr, 0, m, &cVar_p88jmWSr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_5Xn9UTQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YoP3VLL0, 0, m, &cVar_YoP3VLL0_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_RYHbJdQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Twjbn1nc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CzihH7D2_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_9aWy91uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VkNX5Qzf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czY5lvAm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DT0cuwEv_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_WG4AzsqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zmmWZtXR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DwDrQdOk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wOgnvWYu_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_TLXuO23e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y5Fzst1Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K5mrCo3A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KaHWgqpv_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_QxHIo4oY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_btJbAtDN_sendMessage(_c, 0, m);
  cMsg_Jp0M7GgS_sendMessage(_c, 0, m);
  cMsg_LHrffh6N_sendMessage(_c, 0, m);
  cMsg_xWIhQTCu_sendMessage(_c, 0, m);
  cMsg_F6ccr0Jw_sendMessage(_c, 0, m);
  cMsg_9jWLgafD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XjpF1nK9, 0, m, &cVar_XjpF1nK9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YoP3VLL0, 0, m, &cVar_YoP3VLL0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ulx1pPmJ, 0, m, &cVar_Ulx1pPmJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tp4yvzUz, 0, m, &cVar_tp4yvzUz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ql7d0i8F, 0, m, &cVar_ql7d0i8F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QnqRtE5l, 0, m, &cVar_QnqRtE5l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6vgiU36F, 0, m, &cVar_6vgiU36F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iuV04dgX, 0, m, &cVar_iuV04dgX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EgniqhLy, 0, m, &cVar_EgniqhLy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_l1YdJQyP, 0, m, &cVar_l1YdJQyP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rMxbk7XD, 0, m, &cVar_rMxbk7XD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1PZOpDU6, 0, m, &cVar_1PZOpDU6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_55a9xp0p, 0, m, &cVar_55a9xp0p_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_b2N2KHSP, 0, m, &cVar_b2N2KHSP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0IK5MlJ1, 0, m, &cVar_0IK5MlJ1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZqmQOpJV, 0, m, &cVar_ZqmQOpJV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QEatkrc1, 0, m, &cVar_QEatkrc1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w8nnkKme, 0, m, &cVar_w8nnkKme_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1dk98Dpa, 0, m, &cVar_1dk98Dpa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2pSlo38w, 0, m, &cVar_2pSlo38w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_50C7UunF, 0, m, &cVar_50C7UunF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xAJlwTbP, 0, m, &cVar_xAJlwTbP_sendMessage);
  cMsg_Tta34mmN_sendMessage(_c, 0, m);
  cMsg_z8sqZFu3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_9TVUUmEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_llvTrYCS, HV_BINOP_MULTIPLY, 0, m, &cBinop_llvTrYCS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_j7Cy4it0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bvdoFroT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XHza8N0s_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ALeprX6E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Xsr3cgXW_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_r0phQYrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xZModIXV_sendMessage);
  cMsg_aU3FETo4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_NjlkeTyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GeGvr3Oe, HV_BINOP_MULTIPLY, 0, m, &cBinop_GeGvr3Oe_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_9gglx4Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ckBCvs43_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_fB2LZ6mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pBvEOwqa, HV_BINOP_MULTIPLY, 1, m, &cBinop_pBvEOwqa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YLVtW7Ha_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TZjWWy8Y_sendMessage);
  cMsg_ZPoEER9O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_8PO9KVqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nPIj9Dcu, HV_BINOP_MULTIPLY, 0, m, &cBinop_nPIj9Dcu_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_UnqFFYdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g04HkIix_sendMessage(_c, 0, m);
  cMsg_Kq8cJ5AJ_sendMessage(_c, 0, m);
  cMsg_yMElY95W_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_32PNfbFL_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_oKwmmp9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_G2yq7spQ_sendMessage);
  cMsg_sic9MGN2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_1s91C4ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ql7d0i8F, 0, m, &cVar_ql7d0i8F_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CKcSLZe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lnUYSSvd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b9YnVRl4_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_1tw84Dlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ui2d4TXM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hMo3Cpaa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1isjUBzU_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_taw2xMs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yqbmjXMs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IXpwXYPp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QQIEPmwA_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_sWOU9Ez1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E6QbITAw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OPV44hOU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6v6NVf5d_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rBq6vVHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_91t8vYkS, HV_BINOP_MULTIPLY, 0, m, &cBinop_91t8vYkS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_yYqxq99t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0hy5AUAA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_V0GfTFuC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mUoEMsPK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_DrOsq9if_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_3WCaxAeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cecNrKIA_sendMessage);
  cMsg_XrApD5RB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_InLDcuxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LCidfCYi, HV_BINOP_MULTIPLY, 0, m, &cBinop_LCidfCYi_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_TzZrkRss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_rUqIZhED_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_HfKK8hg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M2UJYIcO, HV_BINOP_MULTIPLY, 1, m, &cBinop_M2UJYIcO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DU40Dnqs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DCR8YCB9_sendMessage);
  cMsg_JvOGHvMj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_MbKvlRdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yfuYtUtN, HV_BINOP_MULTIPLY, 0, m, &cBinop_yfuYtUtN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Q7qnlNxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SkxIGYi7_sendMessage(_c, 0, m);
  cMsg_m4PGFqS5_sendMessage(_c, 0, m);
  cMsg_A0mo9PiN_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_F60IAv83_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_WRhUeBAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_U1yqhbTz_sendMessage);
  cMsg_BUXUgl2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_nnl1b4QD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xWfxpODF, 0, m, &cVar_xWfxpODF_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_8TBYdQtc, VOf(Bf0));
    __hv_varread_f(&sVarf_t0iHwBAU, VOf(Bf1));
    __hv_varread_f(&sVarf_DYdNKAJ7, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_N7vnEvhw, VOf(Bf0));
    __hv_varread_f(&sVarf_ytfpN0UH, VOf(Bf1));
    __hv_varread_f(&sVarf_v2D4gYwK, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_O3nHn3Ms, VOf(Bf0));
    __hv_line_f(&sLine_0SOisfAi, VOf(Bf1));
    __hv_line_f(&sLine_zSDPAtTR, VOf(Bf4));
    __hv_line_f(&sLine_TkpjTkU4, VOf(Bf5));
    __hv_line_f(&sLine_2YFvEdlw, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_L0wx5m7x, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_ISv0Xv5s, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_RX9Rt7V5, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_pdTALLqu, VOf(Bf1));
    __hv_line_f(&sLine_Me4kh6A0, VOf(Bf0));
    __hv_line_f(&sLine_gjCJSX0T, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_7NIAuwlb, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_bYuNVGQS, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_QivctcJm, VOf(Bf7));
    __hv_line_f(&sLine_xhXTdJxB, VOf(Bf1));
    __hv_line_f(&sLine_ySQuIKOt, VOf(Bf4));
    __hv_line_f(&sLine_sGVFRZuB, VOf(Bf6));
    __hv_line_f(&sLine_5zYAF9uX, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_FMtR4gzb, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_1aLfzKoY, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_8TBYdQtc, VIf(Bf5));
    __hv_varwrite_f(&sVarf_t0iHwBAU, VIf(Bf0));
    __hv_varwrite_f(&sVarf_DYdNKAJ7, VIf(Bf6));
    __hv_line_f(&sLine_JbsYuMyX, VOf(Bf6));
    __hv_line_f(&sLine_KJnRgbRc, VOf(Bf0));
    __hv_line_f(&sLine_AIFRgkeT, VOf(Bf5));
    __hv_line_f(&sLine_LpgV3paW, VOf(Bf8));
    __hv_line_f(&sLine_UAdmxef8, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_trU8Untm, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_G0HKvdQW, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_XU7zAlrO, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_tzoZym8h, VOf(Bf0));
    __hv_line_f(&sLine_8zxoC1ga, VOf(Bf6));
    __hv_line_f(&sLine_pubH4jLX, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_ldTwZ7lA, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_FZo7Nmp8, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_pwDN8aVu, VOf(Bf1));
    __hv_line_f(&sLine_vXPSzXpM, VOf(Bf0));
    __hv_line_f(&sLine_vQPXzreO, VOf(Bf5));
    __hv_line_f(&sLine_sSudC3EV, VOf(Bf4));
    __hv_line_f(&sLine_T18fqQ5A, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_TqKaXDwl, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_nXoiuc1I, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_N7vnEvhw, VIf(Bf8));
    __hv_varwrite_f(&sVarf_ytfpN0UH, VIf(Bf6));
    __hv_varwrite_f(&sVarf_v2D4gYwK, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
